@@ -187,10 +187,10 @@ class Base_Page(Borg, unittest.TestCase):
         "Setup the required directory structure if it is not already present"
         try:
             self.screenshots_parent_dir = os.path.abspath(
-                os.path.join(os.sep, '../../../..', 'screenshots', self.product))  # Real screencap folder dir
+                os.path.join(os.curdir, '../../../..', 'screenshots', self.product))  # Real screencap folder dir
             if not os.path.exists(self.screenshots_parent_dir):
                 os.makedirs(self.screenshots_parent_dir)
-            self.logs_parent_dir = os.path.abspath(os.path.join(os.sep, '../../../..', 'log',
+            self.logs_parent_dir = os.path.abspath(os.path.join(os.curdir, '../../../..', 'log',
                                                                 self.product))          # Real log file dir base on Base_Logging.py constructor
             if not os.path.exists(self.logs_parent_dir):
                 os.makedirs(self.logs_parent_dir)
